==> kotlin-web-site-ui-4.2.0.tgz: package/out/components/header/nav-scheme.js <==
import { PLAYGROUND_URL, KOTLINLANG_URL } from './consts.js';
const SOLUTIONS_TITLE = 'Solutions';
const MULTIPLATFORM_MOBILE_TITLE = 'Multiplatform Mobile';
const MULTIPLATFORM_MOBILE_URL = `/lp/mobile/`;
const SERVER_SIDE_TITLE = 'Server-side';
const SERVER_SIDE_URL = `/lp/server-side/`;
const WEB_FRONTEND_TITLE = 'Web frontend';
const WEB_FRONTEND_URL = `/docs/js-overview.html`;
const MULTIPLATFORM_OTHERS_TITLE = 'Multiplatform for other platforms';
const MULTIPLATFORM_OTHERS_URL = '/docs/multiplatform.html';
const DATA_SCIENCE_TITLE = 'Data science';
const DATA_SCIENCE_URL = `/docs/data-science-overview.html`;
const ANDROID_TITLE = 'Android';
const ANDROID_URL = `/docs/android-overview.html`;
const DOCS_TITLE = 'Docs';
const DOCS_URL = `/docs/home.html`;
const COMMUNITY_TITLE = 'Community';
const COMMUNITY_URL = `/community/`;
const TEACH_TITLE = 'Teach';
const TEACH_URL = `/education/`;
const PLAY_TITLE = 'Play';
const PLAY_TITLE_FULL = 'Playground';
const PLAY_URL = PLAYGROUND_URL;
const PLAY_HANDSON_URL = `${PLAY_URL}hands-on`;
const PLAY_HANDSON_TITLE = 'Hands-on';
const PLAY_EXAMPLES_URL = `${PLAY_URL}byExample`;
const PLAY_EXAMPLES_TITLE = 'Examples';
const PLAY_KOANS_URL = `${PLAY_URL}koans`;
const PLAY_KOANS_TITLE = 'Koans';
const KOTLIN_DOCS_TITLE = 'Kotlin';
const KOTLIN_DOCS_URL = `/docs/home.html`;
const KMM_DOCS_TITLE = 'KMM';
const KMM_DOCS_URL = `/docs/mobile/home.html`;
const navScheme = [{
  title: SOLUTIONS_TITLE,
  url: null,
  items: [{
    title: MULTIPLATFORM_MOBILE_TITLE,
    url: MULTIPLATFORM_MOBILE_URL
  }, {
    title: MULTIPLATFORM_OTHERS_TITLE,
    url: MULTIPLATFORM_OTHERS_URL
  }, {
    title: SERVER_SIDE_TITLE,
    url: SERVER_SIDE_URL
  }, {
    title: WEB_FRONTEND_TITLE,
    url: WEB_FRONTEND_URL
  }, {
    title: DATA_SCIENCE_TITLE,
    url: DATA_SCIENCE_URL
  }, {
    title: ANDROID_TITLE,
    url: ANDROID_URL
  }]
}, {
  title: DOCS_TITLE,
  url: KOTLIN_DOCS_URL
}, {
  title: COMMUNITY_TITLE,
  url: COMMUNITY_URL
}, {
  title: TEACH_TITLE,
  url: TEACH_URL
}, {
  title: PLAY_TITLE,
  url: null,
  items: [{
    title: PLAY_TITLE_FULL,
    url: PLAY_URL
  }, {
    title: PLAY_HANDSON_TITLE,
    url: PLAY_HANDSON_URL
  }, {
    title: PLAY_EXAMPLES_TITLE,
    url: PLAY_EXAMPLES_URL
  }, {
    title: PLAY_KOANS_TITLE,
    url: PLAY_KOANS_URL
  }]
}];

function getNavScheme(isUrlActive = (url, currentUrl) => url === currentUrl, currentUrl, isPlayground) {
  return navScheme.map(({
    title,
    url,
    items
  }) => {
    if (url && currentUrl) {
      url = makeExternalUrl(url, currentUrl, !!isPlayground);
    }

    const item = {
      title,
      url
    };
    let isActive = isUrlActive(url, currentUrl);
    item.items = items?.map(({
      title,
      url: childUrl
    }) => {
      if (childUrl && currentUrl) {
        childUrl = makeExternalUrl(childUrl, currentUrl, !!isPlayground);
      }

      let childActive = isUrlActive(childUrl, currentUrl);

      if (childActive) {
        isActive = childActive;
      }

      return {
        title,
        url: childUrl,
        isActive: childActive
      };
    }) ?? [];
    item.isActive = isActive;
    return item;
  });
}

function makeExternalUrl(url, currentUrl, isPlayground) {
  if (isPlayground) {
    if (url.startsWith(PLAY_URL)) {
      return url.replace(PLAY_URL, '/');
    } else {
      return `${KOTLINLANG_URL}${url}`;
    }
  }

  return url;
}

export { ANDROID_TITLE, ANDROID_URL, COMMUNITY_TITLE, COMMUNITY_URL, DATA_SCIENCE_TITLE, DATA_SCIENCE_URL, DOCS_TITLE, DOCS_URL, KMM_DOCS_TITLE, KMM_DOCS_URL, KOTLIN_DOCS_TITLE, KOTLIN_DOCS_URL, MULTIPLATFORM_MOBILE_TITLE, MULTIPLATFORM_MOBILE_URL, MULTIPLATFORM_OTHERS_TITLE, MULTIPLATFORM_OTHERS_URL, PLAY_EXAMPLES_TITLE, PLAY_EXAMPLES_URL, PLAY_HANDSON_TITLE, PLAY_HANDSON_URL, PLAY_KOANS_TITLE, PLAY_KOANS_URL, PLAY_TITLE, PLAY_TITLE_FULL, PLAY_URL, SERVER_SIDE_TITLE, SERVER_SIDE_URL, SOLUTIONS_TITLE, TEACH_TITLE, TEACH_URL, WEB_FRONTEND_TITLE, WEB_FRONTEND_URL, getNavScheme };

==> kotlin-web-site-ui-4.4.7.tgz: package/out/components/header/nav-scheme.js <==
import { PLAYGROUND_URL, KOTLINLANG_URL } from './consts.js';
const HOME_TITLE = 'Home';
const HOME_URL = '/';
const SOLUTIONS_TITLE = 'Solutions';
const MULTIPLATFORM_MOBILE_TITLE = 'Multiplatform Mobile';
const MULTIPLATFORM_MOBILE_URL = `/lp/mobile/`;
const SERVER_SIDE_TITLE = 'Server-side';
const SERVER_SIDE_URL = `/lp/server-side/`;
const MULTIPLATFORM_LIBRARIES_TITLE = 'Multiplatform libraries';
const MULTIPLATFORM_LIBRARIES_URL = '/docs/multiplatform-library.html';
const DATA_SCIENCE_TITLE = 'Data science';
const DATA_SCIENCE_URL = `/docs/data-science-overview.html`;
const ANDROID_TITLE = 'Android';
const ANDROID_URL = `/docs/android-overview.html`;
const DOCS_TITLE = 'Docs';
const DOCS_URL = `/docs/home.html`;
const COMMUNITY_TITLE = 'Community';
const COMMUNITY_URL = `/community/`;
const TEACH_TITLE = 'Teach';
const TEACH_URL = `/education/`;
const PLAY_TITLE = 'Play';
const PLAY_TITLE_FULL = 'Playground';
const PLAY_URL = PLAYGROUND_URL;
const PLAY_HANDSON_URL = `${PLAY_URL}hands-on`;
const PLAY_HANDSON_TITLE = 'Hands-on';
const PLAY_EXAMPLES_URL = `${PLAY_URL}byExample`;
const PLAY_EXAMPLES_TITLE = 'Examples';
const PLAY_KOANS_URL = `${PLAY_URL}koans`;
const PLAY_KOANS_TITLE = 'Koans';
const KOTLIN_DOCS_TITLE = 'Kotlin';
const KOTLIN_DOCS_URL = `/docs/home.html`;
const KMM_DOCS_TITLE = 'KMM';
const KMM_DOCS_URL = `/docs/mobile/home.html`;
const navScheme = [{
  title: HOME_TITLE,
  url: HOME_URL
}, {
  title: SOLUTIONS_TITLE,
  url: null,
  items: [{
    title: MULTIPLATFORM_MOBILE_TITLE,
    url: MULTIPLATFORM_MOBILE_URL
  }, {
    title: MULTIPLATFORM_LIBRARIES_TITLE,
    url: MULTIPLATFORM_LIBRARIES_URL
  }, {
    title: SERVER_SIDE_TITLE,
    url: SERVER_SIDE_URL
  }, {
    title: DATA_SCIENCE_TITLE,
    url: DATA_SCIENCE_URL
  }, {
    title: ANDROID_TITLE,
    url: ANDROID_URL
  }]
}, {
  title: DOCS_TITLE,
  url: KOTLIN_DOCS_URL
}, {
  title: COMMUNITY_TITLE,
  url: COMMUNITY_URL
}, {
  title: TEACH_TITLE,
  url: TEACH_URL
}, {
  title: PLAY_TITLE,
  url: null,
  items: [{
    title: PLAY_TITLE_FULL,
    url: PLAY_URL
  }, {
    title: PLAY_HANDSON_TITLE,
    url: PLAY_HANDSON_URL
  }, {
    title: PLAY_EXAMPLES_TITLE,
    url: PLAY_EXAMPLES_URL
  }, {
    title: PLAY_KOANS_TITLE,
    url: PLAY_KOANS_URL
  }]
}];

function getNavScheme(isUrlActive = (url, currentUrl) => url === currentUrl, currentUrl, isPlayground, withoutHomeSection) {
  const controlledNavScheme = withoutHomeSection ? navScheme.slice(1) : navScheme;
  return controlledNavScheme.map(({
    title,
    url,
    items
  }) => {
    if (url && currentUrl) {
      url = makeExternalUrl(url, currentUrl, !!isPlayground);
    }

    const item = {
      title,
      url
    };
    let isActive = isUrlActive(url, currentUrl);
    item.items = items?.map(({
      title,
      url: childUrl
    }) => {
      if (childUrl && currentUrl) {
        childUrl = makeExternalUrl(childUrl, currentUrl, !!isPlayground);
      }

      let childActive = isUrlActive(childUrl, currentUrl);

      if (childActive) {
        isActive = childActive;
      }

      return {
        title,
        url: childUrl,
        isActive: childActive
      };
    }) ?? [];
    item.isActive = isActive;
    return item;
  });
}

function makeExternalUrl(url, currentUrl, isPlayground) {
  if (isPlayground) {
    if (url.startsWith(PLAY_URL)) {
      return url.replace(PLAY_URL, '/');
    } else {
      return `${KOTLINLANG_URL}${url}`;
    }
  }

  return url;
}

export { ANDROID_TITLE, ANDROID_URL, COMMUNITY_TITLE, COMMUNITY_URL, DATA_SCIENCE_TITLE, DATA_SCIENCE_URL, DOCS_TITLE, DOCS_URL, HOME_TITLE, HOME_URL, KMM_DOCS_TITLE, KMM_DOCS_URL, KOTLIN_DOCS_TITLE, KOTLIN_DOCS_URL, MULTIPLATFORM_LIBRARIES_TITLE, MULTIPLATFORM_LIBRARIES_URL, MULTIPLATFORM_MOBILE_TITLE, MULTIPLATFORM_MOBILE_URL, PLAY_EXAMPLES_TITLE, PLAY_EXAMPLES_URL, PLAY_HANDSON_TITLE, PLAY_HANDSON_URL, PLAY_KOANS_TITLE, PLAY_KOANS_URL, PLAY_TITLE, PLAY_TITLE_FULL, PLAY_URL, SERVER_SIDE_TITLE, SERVER_SIDE_URL, SOLUTIONS_TITLE, TEACH_TITLE, TEACH_URL, getNavScheme };
